@@ -1,30 +1,24 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from sql import Null
-from sql.conditionals import Case
-
-from trytond.model import fields
-from trytond.pyson import Not, Eval, Bool
+from trytond.model import sequence_ordered
+from trytond.pyson import Eval, Bool
 from trytond import backend
 from trytond.pool import PoolMeta
 
 __all__ = ['Location']
 
 
-class Location:
+class Location(sequence_ordered()):
     "Stock Location"
     __metaclass__ = PoolMeta
     __name__ = 'stock.location'
-    sequence = fields.Integer('Sequence',
-        states={
-            'readonly': Not(Bool(Eval('active'))),
-            },
-        depends=['active'])
 
     @classmethod
     def __setup__(cls):
         super(Location, cls).__setup__()
-        cls._order.insert(0, ('sequence', 'ASC'))
+        previous_readonly = cls.sequence.states.get('readonly', Bool(False))
+        cls.sequence.states['readonly'] = previous_readonly | ~Eval('active')
+        cls.sequence.depends = ['active']
 
     @classmethod
     def __register__(cls, module_name):
@@ -35,8 +29,3 @@ class Location:
 
         # Migration from 2.4: drop required on sequence
         table.not_null_action('sequence', action='remove')
-
-    @staticmethod
-    def order_sequence(tables):
-        table, _ = tables[None]
-        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
